@@ -260,8 +260,11 @@ sub latex2e_fine_tune_options {
 	$latex2e->{latex} = "platex";
       }
     } elsif ($global->{language} eq "ko") {
-      # for Korean users
-      $latex2e->{latex} = "hlatexp";
+      if ($global->{charset} eq "utf-8") {
+	$latex2e->{latex} = "pdflatex";
+      } else {
+	$latex2e->{latex} = "hlatexp";
+      }
     } elsif ( $global->{language} =~ /^zh/ ) {
       die "$msgheader: Chinese requires utf-8. Aborting ...\n"
 	unless ( $global->{'charset'} eq "utf-8" );
@@ -277,8 +280,10 @@ sub latex2e_fine_tune_options {
     $latex2e->{latex} = "hlatex";       # run hlatex if hlatexp is used
   } elsif  ($latex2e->{latex} eq "platex") {
     $latex2e->{latexopts} = "--kanji=euc"
-  } elsif ($latex2e->{output} eq "pdf" && $latex2e->{latex} eq "latex" ) {
-    $latex2e->{latex} = "pdflatex";
+  } elsif ( $latex2e->{latex} eq "latex" ){
+    if ($latex2e->{output} eq "pdf" ) {
+      $latex2e->{latex} = "pdflatex";
+    }
   }
 
   # Fine tune $latex2e->{dvips} for defaults and special cases
@@ -328,13 +333,6 @@ sub latex2e_fine_tune_options {
     }
   }
 
-  # Fine tune some other corner cases
-  # We use jlatex for Japanese encoded (euc-jp) characters.
-  # pdf support for Japanese are not yet. use ps for the time being.
-  ###  if ($global->{charset} eq "nippon") {
-  ###    $latex2e->{output} = "ps" if ($latex2e->{output} eq "pdf");
-  ###  }
-
   ldt_log "  ${msgheader} general info after fine tuning:";
   ldt_log "    format: $global->{format}, charset: $global->{charset}, lang: $global->{language}";
   ldt_log "    latex: $latex2e->{latex}, latexopts: $latex2e->{latexopts}, dvips: $latex2e->{dvips}";
@@ -415,9 +413,6 @@ $latex2e->{postASP} = sub
   mkdir ($tmplatexdir, 0700)
     or die "Could not create \"$tmplatexdir\" directory.\n";
 
-  # Some ko charset fine tunings. To be removed once utf-8 is ready.
-  $global->{charset} = "euc-kr" if ($global->{language} eq "ko");
-
   # Set defaults and fine tune $latex2e->{latex,dvips,output}
   $latex2e = latex2e_fine_tune_options($latex2e);
 
@@ -558,16 +553,23 @@ $latex2e->{postASP} = sub
 	      s/\@\@LANG_PACKAGE\@\@/\\usepackage\[UTF8\]\{ctex\}/;
 	    } elsif ($latex2e->{latex} eq "platex") {
 	      s/\@\@LANG_PACKAGE\@\@/\\UseRawInputEncoding/;
+	    } elsif ( $global->{'language'} eq "ko" ){
+	      my $ko_langpkg;
+	      if ( $global->{'charset'} eq "utf-8" ){
+		$ko_langpkg = "\\usepackage{kotex}";
+	      } elsif ($global->{charset} eq "euc-kr"){
+		my $hlatexopt = ($latex2e->{latex} eq "hlatexp") ?
+		  "[noautojosa]" : "";
+		$ko_langpkg ="\\usepackage" . "$hlatexopt" . "{hangul}";
+	      }
+	      s/\@\@LANG_PACKAGE\@\@/$ko_langpkg/;
 	    } elsif ( $use_babel ) {
 	      s/\@\@LANG_PACKAGE\@\@/\\usepackage\[$latex_language\]\{babel\}/;
 	    } else {
 	      s/^/%%/;
 	    }
 	  }
-	  elsif (/^\\usepackage.epsfig/ && ($global->{charset} eq "euc-kr")) {
-	    $hlatexopt = "[noautojosa]" if ($latex2e->{latex} eq "hlatexp");
-	    $_ = $_ . "\\usepackage" . "$hlatexopt" . "{hangul}\n";
-	  }
+
 	  # Deal with input encoding
 	  elsif ( /\\usepackage\[\@CHARSET\@\]\{inputenc\}/ ) {
 	    if ( $global->{charset} eq "latin" ) {
