@@ -21,6 +21,6 @@
 #define VP(parms) P(parms)
 #endif
 
-NO_RETURN void error VP((char *,...));
+void error VP((char *,...));
 
 extern int fold_general_names;
